@@ -4,7 +4,7 @@ from datetime import date, datetime
 from importlib import resources
 from graphql import GraphQLField, GraphQLObjectType, GraphQLInterfaceType, GraphQLResolveInfo
 from ariadne import load_schema_from_path, make_executable_schema, SchemaDirectiveVisitor, FallbackResolversSetter, \
-    ScalarType
+    ScalarType, UnionType
 from ariadne.graphql import GraphQLError
 from ariadne.asgi import GraphQL
 from ariadne.asgi.handlers import GraphQLHTTPHandler, GraphQLTransportWSHandler
@@ -51,7 +51,7 @@ class NeedPermissionDirective(SchemaDirectiveVisitor):
 
 class DBModelDirective(SchemaDirectiveVisitor):
     def visit_object(self, object_: GraphQLObjectType) -> GraphQLObjectType:
-        object_.__tablename__ = self.args['table_name']
+        object_.__modelname__ = self.args['model_name']
         return object_
 
 
@@ -146,6 +146,15 @@ class DBRollbackExtension(Extension):
 
 # Custom Scalars
 
+
+model_types = UnionType('ModelTypes')
+
+
+@model_types.type_resolver
+def resolve_model_types(obj, *_):
+    return obj.__typename
+
+
 date_scalar = ScalarType("Date")
 
 
@@ -226,7 +235,7 @@ def create_graphql(schema_path, bindables: list[SchemaBindable], debug: bool):
     with resources.path('st_microservice', 'base.graphql') as common_filename:
         type_defs_common = load_schema_from_path(common_filename)
 
-    schema = make_executable_schema([type_defs, type_defs_common], bindables, date_scalar, datetime_scalar, fallback_resolvers, directives={
+    schema = make_executable_schema([type_defs, type_defs_common], bindables, model_types, date_scalar, datetime_scalar, fallback_resolvers, directives={
         'no_authentication': NoAuthenticationDirective,
         'need_permission': NeedPermissionDirective,
         'db_model': DBModelDirective,
